/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../common"
import "../common/ClockUtils.js" as Utils

ClockBase {
    id: alarmFace

    property alias showSetupMessage: setupMessage.visible
    property bool isMilitaryFormat: appSetting.contents.timeFormat === "12-hour" ? false : true

    showSecondHand: false

    onMinutesChanged: innerLabel.text = Utils.convertTime(Utils.hourstoCirclePosition(hours), minutes, 0, appSetting.contents.timeFormat)
    onHoursChanged: innerLabel.text = Utils.convertTime(Utils.hourstoCirclePosition(hours), minutes, 0, appSetting.contents.timeFormat)
    onIsMilitaryFormatChanged: innerLabel.text = Utils.convertTime(Utils.hourstoCirclePosition(hours), minutes, 0, appSetting.contents.timeFormat)

    innerLabel.visible: !setupMessage.visible
    innerLabel.font.pixelSize: !isMilitaryFormat ? units.dp(31): units.dp(41)
    innerLabel.text: Utils.convertTime(Utils.hourstoCirclePosition(hours), minutes, 0, appSetting.contents.timeFormat)

    Label {
        id: setupMessage
        objectName: "labelAlarmSetup"

        parent: alarmFace.centerItem
        width: parent.width; height: width;
        anchors.centerIn: parent
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        color: Theme.palette.normal.baseText

        fontSize: "large"
        text: i18n.tr("Long press to setup an alarm")
        wrapMode: Text.WordWrap
    }
}
