/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

Qt.include("../common/ClockUtils.js")

var db = null;

// Opens the local db if not already open. On the first call creates the table
function openDB () {
    if(db !== null) return;

    db = LocalStorage.openDatabaseSync("ubuntu-clock-app", "", "Sunrise and Sunset Database", 1000);

    try {
        db.transaction(function(tx){
            tx.executeSql('CREATE TABLE IF NOT EXISTS Easteregg(key INTEGER PRIMARY KEY, date TEXT, riseTime TEXT, setTime TEXT)');
            var table  = tx.executeSql("SELECT * FROM Easteregg");
            if (table.rows.length == 0) {
                tx.executeSql('INSERT INTO Easteregg VALUES(?, ?, ?, ?)', [1, '', '', '']);
            };
        });
    } catch (err) {
        console.error("Error creating table in Sunrise/Sunset database: " + err);
    };
}

//Read date last checked from DB
function getSavedData () {

    openDB();

    var result = new Array();
    try {
        db.readTransaction(
            function(tx){
                var res = tx.executeSql('SELECT * FROM Easteregg WHERE key = 1');
                if (res.rows.length > 0) {
                    result[0] = new Array();
                    result[0][0] = res.rows.item(0).key;
                    result[0][1] = res.rows.item(0).date;
                    result[0][2] = res.rows.item(0).riseTime;
                    result[0][3] = res.rows.item(0).setTime;
                };
            });
    } catch (err) {
        console.error("Error getting sunrise/sunset last checked date: " + err);
    }
    return result;
}

function saveSunTimes (date, sunRise, sunSet) {
    openDB();
    try {
        db.transaction(function(tx){
            var res = tx.executeSql('UPDATE Easteregg SET date = ?, riseTime = ?, setTime = ? WHERE key = 1', [date, sunRise, sunSet]);
            console.log("Saving Sunrise/Sunset times to disk");
        });
    } catch (err) {
        console.error("Error saving sunrise/sunset times: " + err);
    };
}
