/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alessandro Pozzi <signor.hyde@gmail.com>
 *              Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Renato Araujo Oliveira Filho <renato.filho@canonical.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import "../common/ClockUtils.js" as Utils
import "StopwatchSupport.js" as SScript
import "../common"

Page {
    id: stopwatchPage

    property alias lapStart: laps.lapStart

    Component.onCompleted: Utils.log("StopwatchPage loaded");

    // Timer which runs every 100 microseconds to update the stopwatch label
    Timer {
        id: stopWatchLabelUpdate;

        interval: 100;
        repeat: true;
        onTriggered: analogStopwatch.innerLabel.text = SScript.timeToString(analogStopwatch.hours, analogStopwatch.minutes, analogStopwatch.seconds, analogStopwatch.milliseconds)
    }

    ListModel {
        id: laps

        property int lapStart: 0;

        function push() {
            insert(0, {"time" : (analogStopwatch.totalTime - lapStart),
                       "label": SScript.currentLapLabel(analogStopwatch.totalTime, lapStart)})
            lapStart = analogStopwatch.totalTime
        }
    }

    // Items within this container will move up/down depending on the state.
    Flickable {
        id: stopwatchAnimationContainer

        clip: true
        anchors.fill: parent
        contentWidth: parent.width
        contentHeight: analogStopwatch.height + analogStopwatch.anchors.topMargin + listLap.height + listLap.anchors.topMargin + units.gu(3)

        // Component which draws the analog stopwatch face, controls the timer and calculates the time.
        StopwatchFace {
            id: analogStopwatch
            objectName: "stopwatchFace"

            anchors {
                top: parent.top
                topMargin: units.gu(10)
                horizontalCenter: parent.horizontalCenter
            }

            innerLabel.text: SScript.timeToString(hours, minutes, seconds, milliseconds)

            onClicked: {
                if(analogStopwatch.timerStatus == false) {
                    analogStopwatch.start()
                    stopWatchLabelUpdate.start()
                    if (analogStopwatch.flag) {
                        analogStopwatch.startTime = new Date().getTime();
                        analogStopwatch.flag = false;
                    }
                    else {
                        analogStopwatch.delay = Math.abs(new Date().getTime() - analogStopwatch.stopTime);
                        analogStopwatch.startTime = analogStopwatch.startTime + analogStopwatch.delay;
                    }
                } else {
                    analogStopwatch.stop()
                    stopWatchLabelUpdate.stop()
                    analogStopwatch.stopTime = new Date().getTime();
                }
            }
        }

        ImageButton {
            id: resetButton
            objectName: "resetButton"

            anchors { top: analogStopwatch.bottom; topMargin: units.gu(4); left: parent.left; leftMargin: units.gu(4) }
            buttonImage: Qt.resolvedUrl("../images/reset_icon.svg");
            buttonLabel: i18n.tr("Reset");

            onClicked: {
                analogStopwatch.stop()
                analogStopwatch.reset();
                analogStopwatch.innerLabel.text = SScript.timeToString(0, 0, 0, 0);
                lapStart = 0;
                laps.clear();
            }
        }

        ImageButton {
            id: lapButton
            objectName: "lapButton"

            anchors { top: analogStopwatch.bottom; topMargin: units.gu(4); right: parent.right; rightMargin: units.gu(4) }
            buttonImage: Qt.resolvedUrl("../images/lap_icon.svg");
            buttonLabel: i18n.tr("Lap");
            mirrorLayout: true;

            enabled: analogStopwatch.timerStatus == true ? true : false;

            onClicked: {
                laps.push();
                analogStopwatch.blipLocation = analogStopwatch.seconds
                analogStopwatch.blipVisible = true
            }
        }

        // ListView to display the current lap and recorded lap information.
        LapList {
            id: listLap
            lapModel: laps
            anchors { left: parent.left; right: parent.right; top: analogStopwatch.bottom; topMargin: listLap.dynamicTopSpacing }
            dynamicTopSpacing: stopwatchPage.height - stopwatchPage.header.height - analogStopwatch.height - headerHeight - analogStopwatch.anchors.topMargin - dividerHeight;
        }
    }
}
