/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Themes.Ambiance 0.1
import "../common"
import "../common/ClockUtils.js" as Utils

Column {
    id: listPreset
    
    property int dynamicTopSpacing
    property alias dividerHeight: divider.height
    property alias headerHeight: locationHeader.height
    property alias listIndex: listTimerPreset.currentIndex

    // Function to calculate and print the minutes and seconds from the total time as a string
    function getstringTimer(time) {
        var minutes, seconds;

        seconds = time % 60
        time = Math.floor(time / 60)
        minutes = time % 60

        return Utils.zeroleft(minutes, 1) + ":" + Utils.zeroleft(seconds, 2);
    }

    height: childrenRect.height
    
    ListItem.ThinDivider { id: divider }
    
    ListItem.Header {
        id: locationHeader
        Label {
            text: i18n.tr("Presets")
            anchors { verticalCenter: parent.verticalCenter; left: parent.left; leftMargin: units.gu(2) }
            color: Theme.palette.normal.baseText
            fontSize: "medium"
        }
    }
    
    ListView {
        id: listTimerPreset
        
        clip: true
        currentIndex: -1
        model: presetModel
        height: 5 * units.gu(6) + units.gu(1)
        anchors { left: parent.left; right: parent.right }        
        
        delegate: ListItem.Standard {
            objectName: "preset" + index
            Label {
                id: presetTextLabel // Needs by autopilot
                objectName: "presetTextLabel" + index                
                text: label
                fontSize: "large";
                color: Theme.palette.normal.baseText
                anchors { verticalCenter: parent.verticalCenter; left: parent.left; leftMargin: units.gu(3) }
            }
            
            Label {
                id: presetTimeLabel
                objectName: "presetTimerLabel"
                fontSize: "large"
                text: getstringTimer(seconds);
                color: Theme.palette.normal.baseText
                anchors { verticalCenter: parent.verticalCenter; right: parent.right; rightMargin: units.gu(2) }
            }
            
            selected: listTimerPreset.currentIndex == index
            removable: true
            confirmRemoval: true
            
            onItemRemoved: {
                presetModel.removePreset(index);
                if (presetModel.count == 0)
                    timerAnimationContainer.contentY = tempPosition
            }

            onClicked: {
                if (!timerOn) {
                    // If a user chooses a preset after a pause we have to reset the Timer
                    if (analogTimer.state === 'PAUSE') {
                        analogTimer.state = '';
                        analogTimer.totalTime = analogTimer.remTime = analogTimer.pauseTime = 0;
                    }
                    analogTimer.ssToTime(seconds);
                    listTimerPreset.currentIndex = index
                    timerAnimationContainer.contentY = tempPosition
                    namePreset.text = label;
                    namePreset.cursorPosition = 0;
                    tempNamePreset = label;
                }
            }
        }
    }
}
